@@ -2,10 +2,20 @@
  *
  * Authors: Vincenzo Ciaschini - Vincenzo.Ciaschini@cnaf.infn.it 
  *
- * Copyright (c) 2002-2009 INFN-CNAF on behalf of the EU DataGrid
- * and EGEE I, II and III
- * For license conditions see LICENSE file or
- * http://www.apache.org/licenses/LICENSE-2.0.txt
+ * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
+ * See http://www.eu-egee.org/partners/ for details on the copyright holders.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * Parts of this code may be based upon or even include verbatim pieces,
  * originally written by other people, in which case the original header
@@ -13,6 +23,8 @@
  *
  *********************************************************************/
 
+#include "api_util.h"
+
 extern "C" {
 #include "config.h"
 #include "replace.h"
@@ -41,15 +53,11 @@ extern "C" {
 
 #include "Client.h"
 
-#include "voms_api.h"
-
 #include <iostream>
 #include <iomanip>
 #include <fstream>
 #include <map>
 
-#include "api_util.h"
-
 #include "vomsxml.h"
 #include "ccval.h"
 
@@ -61,6 +69,7 @@ static bool dncompare(const std::string &mut, const std::string &fixed);
 static bool readdn(std::ifstream &file, char *buffer, int buflen);
 
 extern std::map<vomsdata*, vomsspace::internal*> privatedata;
+extern pthread_mutex_t privatelock;
 
 static void normalize(std::string &name)
 {
@@ -838,7 +847,9 @@ vomsdata::my_conn(const std::string &hostname, int port, const std::string &cont
   STACK_OF(X509) *cert_chain = NULL;
   EVP_PKEY       *upkey = NULL;
 
+  pthread_mutex_lock(&privatelock);
   vomsspace::internal *data = privatedata[this];
+  pthread_mutex_unlock(&privatelock);
 
   ucert      = data->cert;
   cert_chain = data->chain;
