@@ -2,10 +2,20 @@
  *
  * Authors: Vincenzo Ciaschini - Vincenzo.Ciaschini@cnaf.infn.it 
  *
- * Copyright (c) 2002-2009 INFN-CNAF on behalf of the EU DataGrid
- * and EGEE I, II and III
- * For license conditions see LICENSE file or
- * http://www.apache.org/licenses/LICENSE-2.0.txt
+ * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
+ * See http://www.eu-egee.org/partners/ for details on the copyright holders.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * Parts of this code may be based upon or even include verbatim pieces,
  * originally written by other people, in which case the original header
@@ -80,7 +90,7 @@ extern char *Encode(const char *, int, int *, int);
 extern int AC_Init(void);
 
 std::map<vomsdata*, vomsspace::internal*> privatedata;
-
+pthread_mutex_t privatelock = PTHREAD_MUTEX_INITIALIZER;
 
 vomsdata::Initializer::Initializer(Initializer &) {}
 vomsdata::Initializer::Initializer()
@@ -171,14 +181,18 @@ vomsdata::vomsdata(std::string voms_dir, std::string cert_dir) :  ca_cert_dir(ce
   duration = 0;
 
   vomsspace::internal *data = new vomsspace::internal();
+  pthread_mutex_lock(&privatelock);
   privatedata[this] = data;
+  pthread_mutex_unlock(&privatelock);
 }
 
 
 vomsdata::~vomsdata()
 {
+  pthread_mutex_lock(&privatelock);
   vomsspace::internal *data = privatedata[this];
   (void)privatedata.erase(this);
+  pthread_mutex_unlock(&privatelock);
   delete data;
 }
 
@@ -915,7 +929,9 @@ bool vomsdata::LoadCredentials(X509 *cert, EVP_PKEY *pkey, STACK_OF(X509) *chain
   STACK_OF(X509) *cert_chain = NULL;
   EVP_PKEY       *upkey = NULL;
 
+  pthread_mutex_lock(&privatelock);
   vomsspace::internal *data = privatedata[this];
+  pthread_mutex_unlock(&privatelock);
 
   /* The condition below should never be true. */
   if (!data)
