@@ -2,10 +2,20 @@
  *
  * Authors: Vincenzo Ciaschini - Vincenzo.Ciaschini@cnaf.infn.it
  *
- * Copyright (c) 2002-2009 INFN-CNAF on behalf of the EU DataGrid
- * and EGEE I, II and III
- * For license conditions see LICENSE file or
- * http://www.apache.org/licenses/LICENSE-2.0.txt
+ * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
+ * See http://www.eu-egee.org/partners/ for details on the copyright holders.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * Parts of this code may be based upon or even include verbatim pieces,
  * originally written by other people, in which case the original header
@@ -38,6 +48,7 @@ import java.util.NoSuchElementException;
 import java.util.Set;
 import java.util.Stack;
 import java.util.TreeSet;
+import java.util.HashSet;
 import java.util.Vector;
 
 import javax.security.auth.x500.X500Principal;
@@ -894,7 +905,12 @@ public class PKIVerifier {
                     }
                     {
                         Set criticalExts = candidateCRL.getCriticalExtensionOIDs();
-                        if ( criticalExts == null || criticalExts.isEmpty() ) {
+
+                        Set permittedCriticals = new HashSet();
+                        permittedCriticals.add("2.5.29.28");
+
+                        if ( criticalExts == null || criticalExts.isEmpty() ||
+                             (!criticalExts.isEmpty() && permittedCriticals.containsAll(criticalExts))) {
                             if ( candidateCRL.getIssuerX500Principal().equals(
                                     issuer.getSubjectX500Principal() ) ) {
                                 if ( candidateCRL.getNextUpdate().compareTo(
