@@ -3,10 +3,20 @@
  * Authors: Vincenzo Ciaschini - Vincenzo.Ciaschini@cnaf.infn.it 
  *          Valerio Venturi - Valerio.Venturi@cnaf.infn.it 
  *
- * Copyright (c) 2002-2009 INFN-CNAF on behalf of the EU DataGrid
- * and EGEE I, II and III
- * For license conditions see LICENSE file or
- * http://www.apache.org/licenses/LICENSE-2.0.txt
+ * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
+ * See http://www.eu-egee.org/partners/ for details on the copyright holders.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * Parts of this code may be based upon or even include verbatim pieces,
  * originally written by other people, in which case the original header
@@ -15,6 +25,7 @@
  *********************************************************************/
 
 #include "config.h"
+#include "voms_api.h"
 
 extern "C" {
 #include <stdio.h>
@@ -43,9 +54,6 @@ extern "C" {
 #include "options.h"
 #include "vomsxml.h"
 
-
-#include <voms_api.h>
-
 #include "vomsclient.h"
 #include "fqan.h"
 #include "contact.hpp"
@@ -1181,10 +1189,10 @@ bool Client::CreateProxy(std::string data, std::string filedata, AC ** aclist, i
       os << "language:" << policylang;
 
       if (pathlength != -1) 
-	os << ",pathlen:" << pathlength;
+        os << ",pathlen:" << pathlength;
 
       if (!policy.empty())
-	os << ",policy:text:" << policy;
+        os << ",policy:text:" << policy;
       value = strdup(os.str().c_str());
     }
 
@@ -1193,14 +1201,16 @@ bool Client::CreateProxy(std::string data, std::string filedata, AC ** aclist, i
       value = NULL;
     } else {
       if (nativeopenssl) {
-	X509V3_CTX ctx;
-	X509V3_set_ctx(&ctx, NULL, NULL, NULL, NULL, 0L);
-	ctx.db = (void*)&ctx;
-	ex7 = X509V3_EXT_conf_nid(NULL, &ctx, OBJ_obj2nid(OBJ_txt2obj(PROXYCERTINFO_V4,1)), (char*)value);
-	free(value);
+        X509V3_CTX ctx;
+        X509V3_set_ctx(&ctx, NULL, NULL, NULL, NULL, 0L);
+        ctx.db = (void*)&ctx;
+        X509V3_CONF_METHOD method = { NULL, NULL, NULL, NULL };
+        ctx.db_meth = &method;
+        ex7 = X509V3_EXT_conf_nid(NULL, &ctx, OBJ_obj2nid(OBJ_txt2obj(PROXYCERTINFO_V4,1)), (char*)value);
+        free(value);
       }
       else
-	ex7 = X509V3_EXT_conf_nid(NULL, NULL, OBJ_obj2nid(OBJ_txt2obj(PROXYCERTINFO_V4,1)), (char*)value);
+        ex7 = X509V3_EXT_conf_nid(NULL, NULL, OBJ_obj2nid(OBJ_txt2obj(PROXYCERTINFO_V4,1)), (char*)value);
       value = NULL;
     }
 
