@@ -2,10 +2,20 @@
  *
  * Authors: Vincenzo Ciaschini - Vincenzo.Ciaschini@cnaf.infn.it
  *
- * Copyright (c) 2002-2009 INFN-CNAF on behalf of the EU DataGrid
- * and EGEE I, II and III
- * For license conditions see LICENSE file or
- * http://www.apache.org/licenses/LICENSE-2.0.txt
+ * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
+ * See http://www.eu-egee.org/partners/ for details on the copyright holders.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * Parts of this code may be based upon or even include verbatim pieces,
  * originally written by other people, in which case the original header
@@ -764,12 +774,22 @@ VOMSServer::Execute(EVP_PKEY *key, X509 *issuer, X509 *holder, X509 *peer_cert,
 
   if (!newdb->operation(OPERATION_GET_USER, &uid, holder)) {
     int code;
+    std::string message;
     LOG(logh, LEV_ERROR, T_PRE, "Error in executing request!");
     LOG(logh, LEV_ERROR, T_PRE, newdb->errorMessage());
     code = newdb->error();
+    char *mes = newdb->errorMessage();
+    if (mes) 
+      message = std::string(mes);
+    else
+      message = "unknown";
+  
     db->releaseSession(newdb);
 
-    if (code != ERR_NO_DB) {
+    if (code == ERR_USER_SUSPENDED) {
+      err.num = ERR_SUSPENDED;
+      err.message = std::string("User is currently suspended!\nSuspension reason: ") + message;
+    } else if (code != ERR_NO_DB) {
       err.num = ERR_NOT_MEMBER;
       err.message = voname + ": User unknown to this VO.";
     }
@@ -942,6 +962,24 @@ VOMSServer::Execute(EVP_PKEY *key, X509 *issuer, X509 *holder, X509 *peer_cert,
                      index->fqan.end());
     }
   
+    // Adjust for long/short format
+    if (!short_flags && !fqans.empty()) {
+      std::vector<std::string> newfqans(fqans);
+      fqans.clear();
+      std::vector<std::string>::iterator i = newfqans.begin();
+      while (i != newfqans.end()) {
+        std::string fqan = *i;
+        LOGM(VARP, logh, LEV_DEBUG, T_PRE, "Initial FQAN: %s", fqan.c_str());
+        if (fqan.find("/Role=") != std::string::npos)
+          fqan += "/Capability=NULL";
+        else
+          fqan += "/Role=NULL/Capability=NULL";
+        LOGM(VARP, logh, LEV_DEBUG, T_PRE, "Processed FQAN: %s", fqan.c_str());
+        fqans.push_back(fqan);
+        i++;
+      }
+    }
+
     /* if attributes were found, only release an intersection beetween the requested and the owned */
     std::vector<std::string>::iterator end = fqans.end();
     bool subset = false;
@@ -961,23 +999,6 @@ VOMSServer::Execute(EVP_PKEY *key, X509 *issuer, X509 *holder, X509 *peer_cert,
                     attribs.end());
     }
 
-    // Adjust for long/short format
-    if (!short_flags && !fqans.empty()) {
-      std::vector<std::string> newfqans(fqans);
-      fqans.clear();
-      std::vector<std::string>::iterator i = newfqans.begin();
-      while (i != newfqans.end()) {
-        std::string fqan = *i;
-        LOGM(VARP, logh, LEV_DEBUG, T_PRE, "Initial FQAN: %s", fqan.c_str());
-        if (fqan.find("/Role=") != std::string::npos)
-          fqan += "/Capability=NULL";
-        else
-          fqan += "/Role=NULL/Capability=NULL";
-        LOGM(VARP, logh, LEV_DEBUG, T_PRE, "Processed FQAN: %s", fqan.c_str());
-        fqans.push_back(fqan);
-        i++;
-      }
-    }
 
     // no attributes can be send
     if (fqans.empty()) {
