@@ -3,10 +3,20 @@
  * Authors: Vincenzo Ciaschini - Vincenzo.Ciaschini@cnaf.infn.it 
  *          Valerio Venturi - Valerio.Venturi@cnaf.infn.it 
  *
- * Copyright (c) 2002-2009 INFN-CNAF on behalf of the EU DataGrid
- * and EGEE I, II and III
- * For license conditions see LICENSE file or
- * http://www.apache.org/licenses/LICENSE-2.0.txt
+ * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
+ * See http://www.eu-egee.org/partners/ for details on the copyright holders.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * Parts of this code may be based upon or even include verbatim pieces,
  * originally written by other people, in which case the original header
@@ -24,6 +34,8 @@
 #include <sstream>
 #include <algorithm>
 
+#include <voms_api.h>
+
 extern "C" {
 #include <stdio.h>
 #include <unistd.h>
@@ -47,8 +59,6 @@ VOLIST *volist = NULL;
   extern FILE *yyin;
 }
 
-#include <voms_api.h>
-
 #include "vomsfake.h"
 #include "ccwrite.h"
 
@@ -686,6 +696,8 @@ bool Fake::CreateProxy(std::string data, std::string filedata, AC ** aclist, BIG
         X509V3_CTX ctx;
         X509V3_set_ctx(&ctx, NULL, NULL, NULL, NULL, 0L);
         ctx.db = (void*)&ctx;
+        X509V3_CONF_METHOD method = { NULL, NULL, NULL, NULL };
+        ctx.db_meth = &method;
         ex7 = X509V3_EXT_conf_nid(NULL, &ctx, OBJ_obj2nid(OBJ_txt2obj(PROXYCERTINFO_V4,1)), (char*)value);
         free(value);
       }
